-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AloftHighlight")
local SML = AceLibrary("SharedMedia-1.0")
local SML_statusbar = SML:List("statusbar")

-----------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Highlight"] = true,
	["Mouseover highlight options"] = true,
	["Color"] = true,
	["Sets the highlight color"] = true,
	["Texture"] = true,
	["Sets the highlight texture"] = true,
	["Blend Mode"] = true,
	["Sets the blend mode for the highlight texture"] = true,
} end)

-----------------------------------------------------------------------------

local AloftHighlight = Aloft:NewModule("Highlight", "AceEvent-2.0")
AloftHighlight.db = Aloft:AcquireDBNamespace("highlight")
Aloft:RegisterDefaults("highlight", "profile", {
	color			= { 1, 1, 0, 0.25 },
	texture			= "Blizzard",
	blendMode		= "ADD",
})

Aloft.Options.args.highlight =
{
	type = 'group',
	name = L["Highlight"],
	desc = L["Mouseover highlight options"],
	disabled = function() return not Aloft:IsActive() end,
	args =
	{
		color =
		{
			type = 'color',
			name = L["Color"],
			desc = L["Sets the highlight color"],
			get = function() return unpack(AloftHighlight.db.profile.color) end,
			set = function(r, g, b, a) AloftHighlight.db.profile.color = { r, g, b, a } AloftHighlight:UpdateAll() end,
			hasAlpha = true
		},
		texture =
		{
			type = "text", 
			name = L["Texture"], 
			desc = L["Sets the highlight texture"],
			get = function() return AloftHighlight.db.profile.texture end,
			set = function(v) AloftHighlight.db.profile.texture = v AloftHighlight:UpdateAll() end,
			validate = SML_statusbar,
		},
		mode =
		{
			type = "text",
			name = L["Blend Mode"],
			desc = L["Sets the blend mode for the highlight texture"],
			get = function() return AloftHighlight.db.profile.blendMode end,
			set = function(v) AloftHighlight.db.profile.blendMode = v AloftHighlight:UpdateAll() end,
			validate = { "BLEND", "ADD" },
		},
	},
}

-----------------------------------------------------------------------------

function AloftHighlight:UpdateAll()
	for aloftData in Aloft:IterateNameplates() do	
		self:SetupFrame(aloftData)
	end
end

-----------------------------------------------------------------------------

function AloftHighlight:OnEnable()
	self:RegisterEvent("SharedMedia_SetGlobal", function(mediatype, override)
		if mediatype == "statusbar" then
			self:UpdateAll()
		end
	end)

	self:RegisterEvent("Aloft:SetAll", function(type, value)
		if self.db.profile[type] then
			self.db.profile[type] = value
			self:UpdateAll()
		end
	end)

	self:RegisterEvent("Aloft:SetupFrame", "SetupFrame")
	self:RegisterEvent("Aloft:OnNameplateShow", "OnNameplateShow")
	
	self:UpdateAll()
end

function AloftHighlight:OnDisable()
	self:UnregisterAllEvents()
	
	for aloftData in Aloft:IterateNameplates() do
		local highlightFrame = aloftData.highlightFrame
		highlightFrame:ClearAllPoints()
		highlightFrame:SetAllPoints(aloftData.nameplateFrame)
		highlightFrame:SetTexture("Interface\\Tooltips\\Nameplate-Glow")
		highlightFrame:SetBlendMode("ADD")
	end
end

function AloftHighlight:OnNameplateShow(aloftData)
	local highlightFrame = aloftData.highlightFrame
	highlightFrame:ClearAllPoints()
	highlightFrame:SetAllPoints(aloftData.healthBar)
end

function AloftHighlight:SetupFrame(aloftData)
	local highlightFrame = aloftData.highlightFrame

	highlightFrame:ClearAllPoints()
	highlightFrame:SetAllPoints(aloftData.healthBar)
	highlightFrame:SetVertexColor(unpack(self.db.profile.color))	
	highlightFrame:SetTexture(SML:Fetch("statusbar", self.db.profile.texture))
	highlightFrame:SetBlendMode(self.db.profile.blendMode)
end

-----------------------------------------------------------------------------
