-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AloftSpellIcon")

-----------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Spell Icon"] = true,
	["Spell icon placement options"] = true,
	["Enable"] = true,
	["Enable spell icon display on the nameplate"] = true,
	["Anchor"] = true, 
	["Sets the anchor for the spell icon"] = true,
	["Anchor To"] = true, 
	["Sets the relative point on the cast bar to anchor the spell icon"] = true,
	["Size"] = true,
	["Size in pixels of the spell icon"] = true,
	["X Offset"] = true,
	["X offset of the spell icon"] = true,
	["Y Offset"] = true,
	["Y offset of the spell icon"] = true,
} end)

-----------------------------------------------------------------------------

local AloftSpellIcon = Aloft:NewModule("SpellIcon", "AceEvent-2.0")
AloftSpellIcon.db = Aloft:AcquireDBNamespace("spellIcon")
Aloft:RegisterDefaults("spellIcon", "profile", {
	enable			= true,
	point			= "RIGHT",
	relativeToPoint	= "LEFT",
	offsetX			= 0,
	offsetY			= 0,
	size			= 12
})

Aloft.Options.args.spellIcon =
{
	type = 'group',
	name = L["Spell Icon"],
	desc = L["Spell icon placement options"],
	disabled = function() return not Aloft:IsActive() end,
	args =
	{
		enable = 
		{
			type = 'toggle',
			name = L["Enable"],
			desc = L["Enable spell icon display on the nameplate"],
			get = function() return AloftSpellIcon.db.profile.enable end,
			set = function(v) AloftSpellIcon.db.profile.enable = v AloftSpellIcon:UpdateAll() end,
			order = 1
		},
		anchor = {
			type = "text", 
			name = L["Anchor"], 
			desc = L["Sets the anchor for the spell icon"],
			disabled = function() return not AloftSpellIcon.db.profile.enable end,
			get = function() return AloftSpellIcon.db.profile.point end,
			set = function(v) AloftSpellIcon.db.profile.point = v AloftSpellIcon:UpdateAll() end,
			validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
		},
		anchorto = {
			type = "text", 
			name = L["Anchor To"], 
			desc = L["Sets the relative point on the cast bar to anchor the spell icon"],
			disabled = function() return not AloftSpellIcon.db.profile.enable end,
			get = function() return AloftSpellIcon.db.profile.relativeToPoint end,
			set = function(v) AloftSpellIcon.db.profile.relativeToPoint = v AloftSpellIcon:UpdateAll() end,
			validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
		},
		size =
		{
			type = 'range',
			name = L["Size"],
			desc = L["Size in pixels of the spell icon"],
			min = 4,
			max = 32,
			step = 1,
			disabled = function() return not AloftSpellIcon.db.profile.enable end,
			get = function() return AloftSpellIcon.db.profile.size end,
			set = function(v) AloftSpellIcon.db.profile.size = v AloftSpellIcon:UpdateAll() end
		},
		offsetX =
		{
			type = 'range',
			name = L["X Offset"],
			desc = L["X offset of the spell icon"],
			min = -32,
			max = 32,
			step = 1,
			disabled = function() return not AloftSpellIcon.db.profile.enable end,
			get = function() return AloftSpellIcon.db.profile.offsetX end,
			set = function(v) AloftSpellIcon.db.profile.offsetX = v AloftSpellIcon:UpdateAll() end
		},
		offsetY =
		{
			type = 'range',
			name = L["Y Offset"],
			desc = L["Y offset of the spell icon"],
			min = -32,
			max = 32,
			step = 1,
			disabled = function() return not AloftSpellIcon.db.profile.enable end,
			get = function() return AloftSpellIcon.db.profile.offsetY end,
			set = function(v) AloftSpellIcon.db.profile.offsetY = v AloftSpellIcon:UpdateAll() end
		},
	},
}

-----------------------------------------------------------------------------

function AloftSpellIcon:UpdateAll()
	for aloftData in Aloft:IterateNameplates() do
		self:SetupFrame(aloftData)
	end
end

-----------------------------------------------------------------------------

function AloftSpellIcon:OnEnable()
	self:RegisterEvent("Aloft:SetupFrame", "SetupFrame")
	self:RegisterEvent("Aloft:OnCastBarShow", "SetupFrame")
	
	self:UpdateAll()
end

function AloftSpellIcon:OnDisable()
	self:UnregisterAllEvents()
	
	for aloftData in Aloft:IterateNameplates() do
		local spellIconFrame = aloftData.spellIconFrame
		spellIconFrame:ClearAllPoints()
		spellIconFrame:SetPoint("CENTER", aloftData.nameplateFrame, "BOTTOMLEFT", 13.33, 10.29)
		spellIconFrame:SetWidth(14.5)
		spellIconFrame:SetHeight(14.5)
		spellIconFrame:SetAlpha(1)
	end
end

function AloftSpellIcon:SetupFrame(aloftData)
	self:PlaceFrame(aloftData.spellIconFrame, aloftData.castBar, self.db.profile)
end

-----------------------------------------------------------------------------
